==> jc-1.4.0.tar.gz: java/beans/beancontext/BeanContext.h <==
// public abstract interface java.beans.beancontext.BeanContext

// class file dependencies
// @dep_class ff15a91ce0368369 java_beans_beancontext_BeanContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_beancontext_BeanContext_H_
#define _JC_java_beans_beancontext_BeanContext_H_

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContext$fields_struct	_jc_java_beans_beancontext_BeanContext$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContext$vtype	_jc_java_beans_beancontext_BeanContext$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContext$fields_struct {
	struct _jc_java_lang_Object$object	*globalHierarchyLock;
};
extern _jc_java_beans_beancontext_BeanContext$fields_struct _jc_java_beans_beancontext_BeanContext$class_fields;

// Static methods
extern void _jc_java_beans_beancontext_BeanContext$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_java_beans_beancontext_BeanContext$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContext$vtype _jc_java_beans_beancontext_BeanContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContext$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContext_H_ */

==> jc-1.4.6.tar.gz: java/beans/beancontext/BeanContext.h <==
// public abstract interface java.beans.beancontext.BeanContext

// class file dependencies
// @dep_class ff15a91ce0368369 java_beans_beancontext_BeanContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_beancontext_BeanContext_H_
#define _JC_java_beans_beancontext_BeanContext_H_

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContext$fields_struct	_jc_java_beans_beancontext_BeanContext$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContext$vtype	_jc_java_beans_beancontext_BeanContext$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContext$fields_struct {
	struct _jc_java_lang_Object$object	*globalHierarchyLock;
};
extern _jc_java_beans_beancontext_BeanContext$fields_struct _jc_java_beans_beancontext_BeanContext$class_fields;

// Static methods
extern void _jc_java_beans_beancontext_BeanContext$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_java_beans_beancontext_BeanContext$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContext$vtype _jc_java_beans_beancontext_BeanContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContext$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContext_H_ */
